@@ -109,10 +109,9 @@ gst_dvd_sub_dec_class_init (GstDvdSubDecClass * klass)
 
   gobject_class->finalize = gst_dvd_sub_dec_finalize;
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&src_template));
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&subtitle_template));
+  gst_element_class_add_static_pad_template (gstelement_class, &src_template);
+  gst_element_class_add_static_pad_template (gstelement_class,
+      &subtitle_template);
 
   gst_element_class_set_static_metadata (gstelement_class,
       "DVD subtitle decoder", "Codec/Decoder/Video",
